@@ -39,6 +39,7 @@ mod stack;
 mod switch;
 mod table;
 mod tabs;
+mod text;
 mod title;
 mod toast;
 mod toolbar;
@@ -85,6 +86,7 @@ pub use stack::*;
 pub use switch::*;
 pub use table::*;
 pub use tabs::*;
+pub use text::*;
 pub use title::*;
 pub use toast::*;
 pub use toolbar::*;
